@@ -162,6 +162,7 @@
     ("psgml" . "xemacs-packages")
     ("psgml-dtds" . "xemacs-packages")
     ("python-modes" . "xemacs-packages")
+    ("re-builder" . "xemacs-packages")
     ("reftex" . "xemacs-packages")
     ("riece" . "xemacs-packages")
     ("rmail" . "xemacs-packages")
@@ -197,6 +198,7 @@
     ("x-symbol" . "xemacs-packages")
     ("xemacs-base" . "xemacs-packages")
     ("xemacs-devel" . "xemacs-packages")
+    ("xetla" . "xemacs-packages")
     ("xlib" . "xemacs-packages")
     ("xslide" . "xemacs-packages")
     ("xslt-process" . "xemacs-packages")
